Crate const_env__value

Crate const_env__value 

Macros

value_from_env
Return the value of an environment variable as a constant literal.

Attribute Macros

from_env
Configure a const or static item from an environment variable.